{ lib, pkgs, config, myconfig,  ... }:
let
    cfg = config.services.myWebsites.DeniseJerome;
    varDir = "/var/lib/ftp/denisejerome";
    env = myconfig.env.websites.denisejerome;
in {
  options.services.myWebsites.DeniseJerome = {
    production = {
      enable = lib.mkEnableOption "enable Denise Jerome's website";
    };
  };

  config = lib.mkIf cfg.production.enable {
    services.webstats.sites = [ { name = "denisejerome.piedsjaloux.fr"; } ];

    security.acme.certs."denisejerome" = config.services.myCertificates.certConfig // {
      domain = "denisejerome.piedsjaloux.fr";
    };

    services.myWebsites.production.vhostConfs.denisejerome = {
      certName    = "denisejerome";
      hosts       = ["denisejerome.piedsjaloux.fr" ];
      root        = varDir;
      extraConfig = [
        ''
        Use Stats denisejerome.piedsjaloux.fr

        <Directory ${varDir}>
          DirectoryIndex index.htm index.html
          Options Indexes FollowSymLinks MultiViews Includes
          AllowOverride AuthConfig
          Require all granted
        </Directory>
          ''
      ];
    };
  };
}
